@@ -18,9 +18,9 @@
  * NO EVENT SHALL SUN MICROSYSTEMS, INC. BE LIABLE FOR ANY SPECIAL, INDIRECT,
  * INCIDENTAL, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
  * FROM USE OF SUCH SOURCE CODE, REGARDLESS OF THE THEORY OF LIABILITY.
- * 
+ *
  * This source code is provided with no support and without any obligation on
- * the part of Sun Microsystems, Inc. to assist in its use, correction, 
+ * the part of Sun Microsystems, Inc. to assist in its use, correction,
  * modification or enhancement.
  *
  * SUN MICROSYSTEMS, INC. SHALL HAVE NO LIABILITY WITH RESPECT TO THE
@@ -68,12 +68,12 @@
  *		Note. under this mechanism, any data item that undergoes
  *		relocation and is then further modified during the execution of
  *		the image before dynodump(3x) is called will lose the
- *		modification that occured during the applications execution.
+ *		modification that occurred during the applications execution.
  *
  * N.B. The above commentary is not quite correct in the flags have been hardwired
  *      to RTLD_SAVREL.
  */
-#pragma ident	"@(#) $Id: dynodump.c,v 1.8 1996/05/23 18:39:21 georgn Exp $ - SMI"
+#pragma ident	"@(#) $Id: dynodump.c,v 1.8 2001/04/12 18:20:43 michaels Exp $ - SMI"
 
 #define __EXTENSIONS__ 1
 
@@ -301,7 +301,7 @@ dynodump(const char * file)
      * If we had a .heap section, then its size is part of the program
      * headers notion of data size.  Because we're only going to output one
      * heap section (ignoring the one in the running binary) we need to
-     * subract the size of that which we're ignoring.
+     * subtract the size of that which we're ignoring.
      */
     if (heap_cache) {
 	edata = S_ROUND((data_phdr->p_vaddr
@@ -492,7 +492,7 @@ dynodump(const char * file)
 
 	/*
 	 * If were inserting the new .heap section, insert the new
-	 * section name and initialize it's virtual address.
+	 * section name and initialize its virtual address.
 	 */
 	if (_addr) {
 	    strs = heap;
