@@ -44,10 +44,12 @@ static unsigned char app_mask_bits[] = {
 #define cursor_height 16
 #define cursor_x_hot 0
 #define cursor_y_hot 0
+#if 0 /* unused */
 static unsigned char cursor_bits[] = {
    0x00, 0x00, 0x02, 0x00, 0x06, 0x00, 0x0e, 0x00, 0x1e, 0x00, 0x3e, 0x00,
    0x7e, 0x00, 0xfe, 0x00, 0xfe, 0x01, 0x3e, 0x00, 0x36, 0x00, 0x62, 0x00,
    0x60, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0x00, 0x00};
+#endif /* unused */
 #define dir_width 42
 #define dir_height 24
 #define dir_x_hot 1
