@@ -41,6 +41,7 @@ Boston, MA 02111-1307, USA.  */
 #define VERTICAL_SCROLLBAR_DRAG_HACK
 
 static int vertical_drag_in_progress = 0;
+extern Lisp_Object mswindows_find_frame (HWND hwnd);
 
 static void
 mswindows_create_scrollbar_instance (struct frame *f, int vertical,
@@ -87,10 +88,22 @@ mswindows_free_scrollbar_instance (struct scrollbar_instance *sb)
     xfree (sb->scrollbar_data);
 }
 
+static void
+unshow_that_mofo (void *handle)
+{
+  ShowScrollBar ((HWND) handle, SB_CTL, 0);
+}
+
 static void
 mswindows_release_scrollbar_instance (struct scrollbar_instance *sb)
 {
-  ShowScrollBar (SCROLLBAR_MSW_HANDLE (sb), SB_CTL, 0);
+  if (gc_in_progress)
+    /* #### way bogus!  need to remove the offending call.
+       see mark_redisplay(). */
+    register_post_gc_action (unshow_that_mofo,
+			     (void *) SCROLLBAR_MSW_HANDLE (sb));
+  else
+    ShowScrollBar (SCROLLBAR_MSW_HANDLE (sb), SB_CTL, 0);
   SCROLLBAR_MSW_SIZE (sb) = 0;
 }
 
@@ -114,7 +127,13 @@ mswindows_update_scrollbar_instance_values (struct window *w,
 					    int new_scrollbar_y)
 {
   int pos_changed = 0;
-  int vert = GetWindowLong (SCROLLBAR_MSW_HANDLE (sb), GWL_STYLE) & SBS_VERT;
+  long styles = GetWindowLong (SCROLLBAR_MSW_HANDLE (sb), GWL_STYLE);
+  int vert = styles & SBS_VERT;
+
+  if (styles == 0) {
+    mswindows_output_last_error("GetWindowLong");
+    return;
+  }
 
 #if 0
   stderr_out ("[%d, %d], page = %d, pos = %d, inhibit = %d\n", new_minimum, new_maximum,
@@ -176,14 +195,45 @@ mswindows_handle_scrollbar_event (HWND hwnd, int code, int pos)
   struct frame *f;
   Lisp_Object win, frame;
   struct scrollbar_instance *sb;
-  SCROLLINFO scrollinfo;
-  int vert = GetWindowLong (hwnd, GWL_STYLE) & SBS_VERT;
-  int value;
+  long styles = GetWindowLong (hwnd, GWL_STYLE);
+  int vert = styles & SBS_VERT;
+
+  if (styles == 0) {
+    mswindows_output_last_error("GetWindowLong");
+    return;
+  }
 
   sb = (struct scrollbar_instance *)GetWindowLong (hwnd, GWL_USERDATA);
-  win = real_window (sb->mirror, 1);
-  frame = XWINDOW (win)->frame;
-  f = XFRAME (frame);
+  if (sb != NULL) 
+    {
+      win = real_window (sb->mirror, 1);
+      /* "0 as the second parameter" refers to the call to real_window
+     above.  This comment was taken from Ben's 21.5 code that differs
+     somewhat from this, I don't think the 21.4 code ever had a 0
+     there.  #### we're still hitting an abort here with 0 as the
+     second parameter, although only occasionally.  It seems that
+     sometimes we receive events for scrollbars that don't exist
+     anymore.  I assume it must happen like this: The user does
+     something that causes a scrollbar to disappear (e.g. Alt-TAB,
+     causing recomputation of everything in the new frame) and then
+     immediately uses the mouse wheel, generating scrollbar events.
+     Both events get posted before we have a chance to process them,
+     and in processing the first, the scrollbar mentioned in the
+     second disappears. */
+      if (NILP (win))
+	return;
+      frame = XWINDOW (win)->frame;
+      f = XFRAME (frame);
+    }
+  else 
+    {
+      /* I'm not sure if this is right, but its much better than
+	 passing an HNWD to real_window() - which is what the previous
+	 code did -- andyp */
+      frame = mswindows_find_frame (GetFocus());
+      f = XFRAME (frame);
+      win = FRAME_SELECTED_WINDOW (f);
+    }
 
   /* SB_LINEDOWN == SB_CHARLEFT etc. This is the way they will
      always be - any Windows is binary compatible backward with
@@ -226,10 +276,13 @@ mswindows_handle_scrollbar_event (HWND hwnd, int code, int pos)
 
     case SB_THUMBTRACK:
     case SB_THUMBPOSITION:
-      scrollinfo.cbSize = sizeof(SCROLLINFO);
-      scrollinfo.fMask = SIF_ALL;
-      GetScrollInfo (hwnd, SB_CTL, &scrollinfo);
-      vertical_drag_in_progress = vert;
+      {
+	int pos;
+	SCROLLINFO scrollinfo;
+	scrollinfo.cbSize = sizeof(SCROLLINFO);
+	scrollinfo.fMask = SIF_ALL;
+	GetScrollInfo (hwnd, SB_CTL, &scrollinfo);
+	vertical_drag_in_progress = vert;
 #ifdef VERTICAL_SCROLLBAR_DRAG_HACK
       if (vert && (scrollinfo.nTrackPos > scrollinfo.nPos))
         /* new buffer position =
@@ -237,7 +290,7 @@ mswindows_handle_scrollbar_event (HWND hwnd, int code, int pos)
 	 *   ((text remaining in buffer at start of drag) *
 	 *    (amount that the thumb has been moved) /
 	 *    (space that remained past end of the thumb at start of drag)) */
-	value = (int)
+	pos = (int)
 	  (scrollinfo.nPos
 	   + (((double)
 	      (scrollinfo.nMax - scrollinfo.nPos)
@@ -246,16 +299,17 @@ mswindows_handle_scrollbar_event (HWND hwnd, int code, int pos)
 	  - 2;	/* ensure that the last line doesn't disappear off screen */
       else
 #endif
-        value = scrollinfo.nTrackPos;
+        pos = scrollinfo.nTrackPos;
       mswindows_enqueue_misc_user_event
 	(frame,
 	 vert ? Qscrollbar_vertical_drag : Qscrollbar_horizontal_drag,
-	 Fcons (win, make_int (value)));
+	 Fcons (win, make_int (pos)));
+      }
       break;
 
     case SB_ENDSCROLL:
 #ifdef VERTICAL_SCROLLBAR_DRAG_HACK
-      if (vertical_drag_in_progress)
+      if (vertical_drag_in_progress && sb)
 	/* User has just dropped the thumb - finally update it */
 	SetScrollInfo (SCROLLBAR_MSW_HANDLE (sb), SB_CTL,
 		       &SCROLLBAR_MSW_INFO (sb), TRUE);
